@@ -5,9 +5,9 @@ use warnings;
 sub try {
     my ($class, $d) = @_;
 
-    return unless index($d->ua, 'Google') > -1;
+    return unless $d->contain('Google');
 
-    if ( index($d->ua, 'Googlebot-Image') > -1 ) {
+    if ( $d->contain('Googlebot-Image') ) {
         my $h = {
             name   => 'Googlebot-Image',
             is_bot => 1,
@@ -21,14 +21,14 @@ sub try {
         return $h;
     }
 
-    if ( index($d->ua, 'Googlebot-News') > -1 ) {
+    if ( $d->contain('Googlebot-News') ) {
         return {
             name   => 'Googlebot-News',
             is_bot => 1,
         };
     }
 
-    if ( index($d->ua, 'Googlebot-Video') > -1 ) {
+    if ( $d->contain('Googlebot-Video') ) {
         my $h = {
             name   => 'Googlebot-Video',
             is_bot => 1,
@@ -42,21 +42,77 @@ sub try {
         return $h;
     }
 
-    if ( index($d->ua, 'FeedFetcher-Google') == 0 ) {
+    if ( $d->contain('Storebot-Google') ) {
+        my $h = {
+            name   => 'Storebot-Google',
+            is_bot => 1,
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!Storebot-Google/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        return Duadua::Util->set_os($d, $h)
+    }
+
+    if ( $d->contain('Google-InspectionTool') ) {
+        my $h = {
+            name   => 'Google-InspectionTool',
+            is_bot => 1,
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!Google-InspectionTool/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        return Duadua::Util->set_os($d, $h)
+    }
+
+    if ( $d->prefix('GoogleOther-') ) {
+        my ($type) = ($d->ua =~ m!^GoogleOther-(Image|Video)/!);
+        $type ||= 'UNKNOWN';
+        my $h = {
+            name   => "GoogleOther-$type",
+            is_bot => 1,
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!^Google-.+/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        return $h;
+    }
+    elsif ( $d->contain('GoogleOther') ) {
+        my $h = {
+            name   => 'GoogleOther',
+            is_bot => 1,
+        };
+
+        if ($d->ua eq 'GoogleOther') {
+            return $h;
+        }
+
+        return Duadua::Util->set_os($d, $h);
+    }
+
+    if ( $d->prefix('FeedFetcher-Google') ) {
         return {
             name   => 'FeedFetcher-Google',
             is_bot => 1,
         };
     }
 
-    if ( index($d->ua, ' AppEngine-Google;') > -1 || index($d->ua, 'AppEngine-Google; ') > -1 ) {
+    if ( $d->contain(' AppEngine-Google;') || $d->contain('AppEngine-Google; ') ) {
         return {
             name   => 'AppEngine-Google',
             is_bot => 1,
         };
     }
 
-    if ( index($d->ua, ' Google-Site-Verification') > -1 ) {
+    if ( $d->contain(' Google-Site-Verification') ) {
         my $h = {
             name   => 'Google-Site-Verification',
             is_bot => 1,
@@ -70,7 +126,7 @@ sub try {
         return $h;
     }
 
-    if ( index($d->ua, ' Google Page Speed Insights') > -1 ) {
+    if ( $d->contain(' Google Page Speed Insights') ) {
         my $h = {
             name   => 'Google Page Speed Insights',
             is_bot => 1,
@@ -78,6 +134,13 @@ sub try {
 
         return Duadua::Util->set_os($d, $h);
     }
+
+    if ( $d->prefix('GoogleProducer;') ) {
+        return {
+            name   => 'GoogleProducer',
+            is_bot => 1,
+        };
+    }
 }
 
 1;
