@@ -6,7 +6,7 @@ use Duadua::Util qw//;
 sub try {
     my ($class, $d) = @_;
 
-    if ( index($d->ua, 'AspiegelBot') > -1 ) {
+    if ( $d->contain('AspiegelBot') ) {
         my $h = {
             name   => 'AspiegelBot',
             is_bot => 1,
