@@ -6,7 +6,7 @@ use Duadua::Util qw//;
 sub try {
     my ($class, $d) = @_;
 
-    if ( index($d->ua, ' Vivaldi/') > -1 ) {
+    if ( $d->contain(' Vivaldi/') ) {
         my $h = {
             name => 'Vivaldi',
         };
